@@ -27,16 +27,10 @@
 #endif
 
 #include <gdk/gdk.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtktreeselection.h>
-#include <libgnomevfs/gnome-vfs-types.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <gtk/gtk.h>
 #include <libgnome/gnome-macros.h>
-#include <libgnomeui/gnome-icon-lookup.h>
+#include <gio/gio.h>
 #include <string.h>
-#include <gdl/gdl-icons.h>
 
 #include "gbf-i18n.h"
 #include "gbf-tree-data.h"
@@ -44,8 +38,10 @@
 #include "gbf-project-model.h"
 #include "gbf-project-view.h"
 
+#define ICON_SIZE 16
+
 struct _GbfProjectViewPrivate {	
-	GdlIcons *icons;
+
 };
 
 enum {
@@ -125,7 +121,6 @@ destroy (GtkObject *object)
 	priv = tree->priv;
 	
 	if (priv) {
-		g_object_unref (priv->icons);
 		g_free (priv);
 		tree->priv = NULL;
 	}
@@ -134,6 +129,35 @@ destroy (GtkObject *object)
 		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
+static GdkPixbuf*
+get_icon (const gchar* uri)
+{
+	const gchar** icon_names;
+	GtkIconInfo* icon_info;
+	GIcon* icon;
+	GdkPixbuf* pixbuf = NULL;
+	GFile* file;
+	GFileInfo* file_info;
+	
+	file = g_file_new_for_uri (uri);
+	file_info = g_file_query_info (file,
+				       G_FILE_ATTRIBUTE_STANDARD_ICON,
+				       G_FILE_QUERY_INFO_NONE,
+				       NULL,
+				       NULL);
+	
+	icon = g_file_info_get_icon(file_info);
+	g_object_get (icon, "names", &icon_names, NULL);
+	icon_info = gtk_icon_theme_choose_icon (gtk_icon_theme_get_default(),
+						icon_names,
+						ICON_SIZE,
+						GTK_ICON_LOOKUP_GENERIC_FALLBACK);
+	pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+	gtk_icon_info_free(icon_info);
+	
+	return pixbuf;
+}
+
 static void
 set_pixbuf (GtkTreeViewColumn *tree_column,
 	    GtkCellRenderer   *cell,
@@ -141,9 +165,9 @@ set_pixbuf (GtkTreeViewColumn *tree_column,
 	    GtkTreeIter       *iter,
 	    gpointer           user_data)
 {
-	GbfProjectView *view = GBF_PROJECT_VIEW (user_data);
+	//GbfProjectView *view = GBF_PROJECT_VIEW (user_data);
 	GbfTreeData *data = NULL;
-	GdkPixbuf *pixbuf;
+	GdkPixbuf *pixbuf = NULL;
 	
 	gtk_tree_model_get (model, iter,
 			    GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
@@ -151,31 +175,24 @@ set_pixbuf (GtkTreeViewColumn *tree_column,
 	
 	switch (data->type) {
 		case GBF_TREE_NODE_TARGET_SOURCE:
-			pixbuf = gdl_icons_get_uri_icon (view->priv->icons,
-							 data->uri);
+		{
+			pixbuf = get_icon (data->uri);
 			break;
+		}
 		case GBF_TREE_NODE_GROUP:
-			pixbuf = gdl_icons_get_folder_icon (view->priv->icons);
+			pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default(),
+							   GTK_STOCK_DIRECTORY,
+							   ICON_SIZE,
+							   GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+							   NULL);
 			break;
 		case GBF_TREE_NODE_TARGET: 
 		{
-			pixbuf = gdl_icons_get_mime_icon (view->priv->icons,
-							  data->mime_type);
-#if 0
-			const gchar* icon;
-			icon = 
-				gnome_icon_lookup(gtk_icon_theme_get_default(),
-						  NULL, NULL, NULL, NULL,
-						  data->mime_type,
-						  0, NULL);
-			if (icon)
-			{
-				pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
-								  icon, 16, 0, NULL);
-			}
-			else
-				pixbuf = NULL;
-#endif
+			pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default(),
+							   GTK_STOCK_CONVERT,
+							   ICON_SIZE,
+							   GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+							   NULL);
 			break;
 		}
 		default:
@@ -319,8 +336,6 @@ gbf_project_view_instance_init (GbfProjectView *tree)
 
 	priv = g_new0 (GbfProjectViewPrivate, 1);
 	tree->priv = priv;
-
-	priv->icons = gdl_icons_new (16);
     
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree), FALSE);
 	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tree), TRUE);
