@@ -39,41 +39,6 @@ gbf_project_load (GbfProject  *project,
 	GBF_PROJECT_GET_CLASS (project)->load (project, path, error);
 }
 
-void
-gbf_project_build (GbfProject  *project,
-		   const gchar *id,
-		   GError     **error)
-{
-	g_return_if_fail (project != NULL);
-	g_return_if_fail (GBF_IS_PROJECT (project));
-	g_return_if_fail (id != NULL);
-	g_return_if_fail (error == NULL || *error == NULL);
-
-	GBF_PROJECT_GET_CLASS (project)->build (project, id, error);
-}
-
-void
-gbf_project_build_default (GbfProject  *project,
-		   	   GError     **error)
-{
-	g_return_if_fail (project != NULL);
-	g_return_if_fail (GBF_IS_PROJECT (project));
-	g_return_if_fail (error == NULL || *error == NULL);
-
-	GBF_PROJECT_GET_CLASS (project)->build (project, GBF_BUILD_ID_DEFAULT, error);
-}
-
-void
-gbf_project_clean (GbfProject *project,
-		   GError    **error)
-{
-	g_return_if_fail (project != NULL);
-	g_return_if_fail (GBF_IS_PROJECT (project));
-	g_return_if_fail (error == NULL || *error == NULL);
-
-	GBF_PROJECT_GET_CLASS (project)->clean (project, error);
-}
-
 gboolean 
 gbf_project_probe (GbfProject  *project,
 		   const gchar *path,
@@ -109,48 +74,6 @@ gbf_project_get_capabilities (GbfProject *project,
 	return GBF_PROJECT_GET_CLASS (project)->get_capabilities (project, error);
 }
 
-/* Build. */
-GList *
-gbf_project_get_build_targets (GbfProject *project,
-			       GError    **error)
-{
-	g_return_val_if_fail (project != NULL, NULL);
-	g_return_val_if_fail (GBF_IS_PROJECT (project), NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
-
-	return GBF_PROJECT_GET_CLASS (project)->get_build_targets (project, error);
-}
-
-void
-gbf_project_add_build_callback (GbfProject       *project,
-				GbfBuildCallback  callback,
-				gpointer          user_data,
-				GError          **error)
-{
-	g_return_if_fail (project != NULL);
-	g_return_if_fail (GBF_IS_PROJECT (project));
-	g_return_if_fail (callback != NULL);
-
-	GBF_PROJECT_GET_CLASS (project)->add_build_callback (project,
-							     callback,
-							     user_data,
-							     error);
-}
-
-void
-gbf_project_remove_build_callback (GbfProject       *project,
-				   GbfBuildCallback  callback,
-				   GError          **error)
-{
-	g_return_if_fail (project != NULL);
-	g_return_if_fail (GBF_IS_PROJECT (project));
-	g_return_if_fail (callback != NULL);
-
-	GBF_PROJECT_GET_CLASS (project)->remove_build_callback (project,
-								callback,
-								error);
-}
-
 /* Groups. */
 gchar * 
 gbf_project_add_group (GbfProject  *project,
@@ -421,6 +344,28 @@ gbf_project_configure (GbfProject *project, GError **error)
 	return GBF_PROJECT_GET_CLASS (project)->configure (project, error);
 }
 
+GList *
+gbf_project_get_config_modules   (GbfProject *project, GError **error)
+{
+	g_return_val_if_fail (project != NULL, NULL);
+	g_return_val_if_fail (GBF_IS_PROJECT (project), NULL);
+	
+	return GBF_PROJECT_GET_CLASS (project)->get_config_modules (project, error);
+}
+
+GList *
+gbf_project_get_config_packages  (GbfProject *project,
+																	const gchar* module,
+																	GError **error)
+{
+	g_return_val_if_fail (project != NULL, NULL);
+	g_return_val_if_fail (module != NULL, NULL);
+	g_return_val_if_fail (GBF_IS_PROJECT (project), NULL);
+	
+	return GBF_PROJECT_GET_CLASS (project)->get_config_packages (project, module,
+																															 error);
+}
+
 /* Types. */
 const gchar * 
 gbf_project_name_for_type (GbfProject  *project,
@@ -460,21 +405,6 @@ gbf_project_class_init (GbfProjectClass *klass)
 {
 	parent_class = g_type_class_peek_parent (klass);
 
-	g_signal_new ("build_start",
-		      G_TYPE_FROM_CLASS (klass),
-		      G_SIGNAL_RUN_LAST,
-		      G_STRUCT_OFFSET (GbfProjectClass, build_start),
-		      NULL, NULL,
-		      g_cclosure_marshal_VOID__VOID,
-		      G_TYPE_NONE, 0);
-	g_signal_new ("build_stop",
-		      G_TYPE_FROM_CLASS (klass),
-		      G_SIGNAL_RUN_LAST,
-		      G_STRUCT_OFFSET (GbfProjectClass, build_stop),
-		      NULL, NULL,
-		      g_cclosure_marshal_VOID__BOOLEAN,
-		      G_TYPE_NONE, 1,
-		      G_TYPE_BOOLEAN);
 	g_signal_new ("project-updated",
 		      G_TYPE_FROM_CLASS (klass),
 		      G_SIGNAL_RUN_LAST,
