@@ -47,11 +47,6 @@ typedef struct _GbfProjectTarget	GbfProjectTarget;
 typedef struct _GbfProjectTargetSource	GbfProjectTargetSource;
 typedef enum   _GbfProjectError		GbfProjectError;
 typedef enum   _GbfProjectCapabilities GbfProjectCapabilities;
-typedef struct _GbfBuildTarget		GbfBuildTarget;
-typedef enum   _GbfBuildType		GbfBuildType;
-typedef enum   _GbfBuildMessage		GbfBuildMessage;
-typedef struct _GbfBuildWarning		GbfBuildWarning;
-typedef struct _GbfBuildError		GbfBuildError;
 
 struct _GbfProjectGroup {
 	gchar   *id;
@@ -90,20 +85,6 @@ enum _GbfProjectError {
 	GBF_PROJECT_ERROR_GENERAL_FAILURE,
 };
 
-struct _GbfBuildTarget {
-	gchar *id;
-	gchar *label;
-	gchar *description;
-};
-
-enum _GbfBuildMessage {
-	GBF_BUILD_START,
-	GBF_BUILD_END,
-	GBF_BUILD_OUTPUT,
-	GBF_BUILD_ERROR,
-	GBF_BUILD_WARNING
-};
-
 enum _GbfProjectCapabilities {
 	GBF_PROJECT_CAN_ADD_NONE              = 0,
 	GBF_PROJECT_CAN_ADD_GROUP             = 1 << 0,
@@ -112,25 +93,6 @@ enum _GbfProjectCapabilities {
 	GBF_PROJECT_CAN_PACKAGES							= 1 << 3
 };
 
-struct _GbfBuildWarning {
-	gchar   *filename;
-	gint     line;
-	gchar   *warning;
-	gchar   *output;
-};
-
-struct _GbfBuildError {
-	gchar   *filename;
-	gint     line;
-	gchar   *error;
-	gchar   *output;
-};
-
-typedef void	(* GbfBuildCallback)	(GbfProject     *project,
-					 GbfBuildMessage msg,
-					 gpointer        data,
-					 gpointer        callback_data);
-
 struct _GbfProject {
 	GObject parent;
 };
@@ -138,10 +100,6 @@ struct _GbfProject {
 struct _GbfProjectClass {
 	GObjectClass parent_class;
 
-	/* Signals. */
-	void                     (* build_start)           (GbfProject *project);
-	void                     (* build_stop)            (GbfProject *project,
-							    gboolean    success);
 	void                     (* project_updated)       (GbfProject *project);
 
 	/* Virtual Table */
@@ -149,11 +107,6 @@ struct _GbfProjectClass {
 	void                     (* load)                  (GbfProject  *project,
 							    const gchar *path,
 							    GError     **error);
-	void                     (* build)                 (GbfProject  *project,
-							    const gchar *id,
-							    GError     **error);
-	void                     (* clean)                 (GbfProject  *project,
-							    GError     **error);
 	gboolean                 (* probe)                 (GbfProject  *project,
 							    const gchar *path,
 							    GError     **error);
@@ -162,17 +115,6 @@ struct _GbfProjectClass {
 	GbfProjectCapabilities   (* get_capabilities)      (GbfProject  *project,
 							    GError     **error);
 
-	/* Build. */
-	GList *                  (* get_build_targets)     (GbfProject       *project,
-							    GError          **error);
-	void                     (* add_build_callback)    (GbfProject       *project,
-							    GbfBuildCallback  callback,
-							    gpointer          user_data,
-							    GError          **error);
-	void                     (* remove_build_callback) (GbfProject       *project,
-							    GbfBuildCallback  callback,
-							    GError          **error);
-
 	/* Groups. */
 	gchar *                  (* add_group)             (GbfProject  *project,
 							    const gchar *parent_id,
@@ -256,13 +198,6 @@ GType                   gbf_project_target_source_get_type (void);
 void                    gbf_project_load                 (GbfProject    *project,
 							  const gchar   *path,
 							  GError       **error);
-void                    gbf_project_build                (GbfProject    *project,
-							  const gchar   *id,
-							  GError       **error);
-void                    gbf_project_build_default        (GbfProject    *project,
-							  GError       **error);
-void                    gbf_project_clean                (GbfProject    *project,
-							  GError       **error);
 gboolean                gbf_project_probe                (GbfProject    *project,
 							  const gchar   *path,
 							  GError       **error);
@@ -271,17 +206,6 @@ void                    gbf_project_refresh              (GbfProject    *project
 GbfProjectCapabilities  gbf_project_get_capabilities     (GbfProject *project,
 							  GError    **error);
 
-/* Build. */
-GList                  *gbf_project_get_build_targets    (GbfProject    *project,
-							  GError       **error);
-void                    gbf_project_add_build_callback   (GbfProject    *project,
-							  GbfBuildCallback callback,
-							  gpointer       user_data,
-							  GError       **error);
-void                    gbf_project_remove_build_callback(GbfProject    *project,
-							  GbfBuildCallback callback,
-							  GError       **error);
-
 /* Groups. */
 gchar                  *gbf_project_add_group            (GbfProject    *project,
 							  const gchar   *parent_id,
